# Animation

Keyframe animation, easing functions, interpolation, and spring physics.

## Keyframe

::: pymotion.animation.keyframe.Keyframe

## KeyframeTrack

::: pymotion.animation.keyframe.KeyframeTrack

## Easing Functions

::: pymotion.animation.easing.get_easing

::: pymotion.animation.easing.cubic_bezier

::: pymotion.animation.easing.steps

::: pymotion.animation.easing.linear

::: pymotion.animation.easing.ease_in_quad

::: pymotion.animation.easing.ease_out_quad

::: pymotion.animation.easing.ease_in_out_quad

::: pymotion.animation.easing.ease_in_cubic

::: pymotion.animation.easing.ease_out_cubic

::: pymotion.animation.easing.ease_in_out_cubic

::: pymotion.animation.easing.ease_in_back

::: pymotion.animation.easing.ease_out_back

::: pymotion.animation.easing.ease_in_elastic

::: pymotion.animation.easing.ease_out_elastic

::: pymotion.animation.easing.ease_out_bounce

::: pymotion.animation.easing.ease_in_bounce

## Interpolation

::: pymotion.animation.interpolator.interpolate

## Spring Physics

::: pymotion.animation.spring.spring
